# Changelog
All changes made in **akademy-matriculation** project will be listed in this file.

The format as follows the recomendations of [Keep a Changelog](https://keepachangelog.com/pt-BR/1.0.0/). And Semantic Versioning


## [1.0.2] - 2026-01-02
### Changed
- Repository hosting transferred to primary maintainer’s GitHub account to ensure continued development and releases


## [1.0.1] - 2025-12-29
### Changed
- Update reports

